<?php

/**
 * Deals with various available shortcodes
 *
 * @link       https://www.pedigreeonline.com
 * @since      1.0.0
 *
 * @package    Pedigree_Online
 * @subpackage Pedigree_Online/shortcodes
 */

class Pedigree_Online_Shortcodes {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function pedigree_shortcode($atts = [], $content = null) {

		/**
		 * This will attempt to find the animal based on a slug or URL and then generate the pedigree
		 */

		$atts = shortcode_atts( array(
        'url' => '',
        'gens' => '', // Don't force the default, it might come from the URL
        'report' => '',
    ), $atts, 'pedigree_online' );

    // Sanity check the report attribute
    $atts['report'] = strtolower(str_replace(' ', '_', $atts['report']));

    $public = new Pedigree_Online_Public($this->plugin_name, $this->version);

    if ( empty( $atts['url'] ) ) {

      return $public->render_notice( __( "No URL was provided. Please include a 'url' attribute with the full link to the report on PedigreeOnline.com" ), 'error' );

    }

    /* Attempt to find the report and slug from the URL provided */
    $functions = new Pedigree_Online_Functions( $this->plugin_name, $this->version );
    $url_data = $functions->parse_url( $atts['url'] );

    if ( empty( $url_data->animal ) ) {

      return $public->render_notice( __( "No animal type could be found in the URL provided -> " . esc_url($atts['url']) ), 'error' );

    }

    if ( empty( $url_data->uuid ) ) {

      return $public->render_notice( __( "No animal identifier could be found in the URL provided -> " . esc_url($atts['url']) ), 'error' );

    }

    /* If the generations was a part of the URL but no atts specified in this shortcode, then let's fill it in now */
    if ( is_numeric( $url_data->gens ) && ! $atts['gens'] ) {

      $atts['gens'] = $url_data->gens;

    } elseif ( ! $atts['gens'] ) {  // If it's blank let's default to 3

      $atts['gens'] = 3;

    }

    /* If we manually passed a report to call, let's do it unless it's not in the list of supported reports */
    if ( ! empty($atts['report']) && in_array($atts['report'], Pedigree_Online::$supported_reports)) {

      $url_data->report = $atts['report'];

    } elseif ( empty($url_data->report) ) {

      $url_data->report = 'pedigree';

    }

    /* Now let's initiate a query for API data */
    $data = $functions->call_api( $url_data->animal, $url_data->uuid, $url_data->report, array('gens' => $atts['gens']) );

    if ( ! $data->result ) {

      return $public->render_notice(__("The query to the API Server failed: <em>" . $data->message . "</em>"), 'error' );

    }

    // See if specific method exists for the report in question
    if (method_exists($public, 'render_'.$url_data->report)) {

      return $public->{'render_'.$url_data->report}( $data );

    }

    return $public->render_notice( __( "No report view file could be found for this type of report: " . $url_data->report ), 'error' );

	}

}
