<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.pedigreeonline.com
 * @since      1.0.0
 *
 * @package    Pedigree_Online
 * @subpackage Pedigree_Online/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Pedigree_Online
 * @subpackage Pedigree_Online/public
 * @author     PedigreeOnline.com, Inc <info@pedigreeonline.com>
 */
class Pedigree_Online_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pedigree_Online_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pedigree_Online_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/frontend.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pedigree_Online_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pedigree_Online_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/frontend.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Render a pedigree based on the animal data
	 *
	 * @since    1.0.0
	 */
	 public function render_pedigree( $data ) {

	    // Buffer output
	    ob_start();
	    require plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/pedigree-online-report-pedigree.php';
	    $html = ob_get_contents();
	    ob_end_clean();

	    return $html;

	 }

	 /**
	 * Recursively renders the pedigree cells
	 *
	 * @since    1.0.0
	 */
	 private function render_pedigree_cells( $animal, $gen=0, &$depth=null ) {

    // If we've hit the end of the line, return nothing
    if ( is_null($animal)) return '';

    $howDeep = 0; // Keep track of how many in front of us
    $father = $this->render_pedigree_cells($animal->father,$gen+1,$howDeep);
    $mother = $this->render_pedigree_cells($animal->mother,$gen+1);

    $endOfPedigree = empty($father) && empty($mother);

    // Report back to the parent that we're one more deep
    $depth = $howDeep + 1;

    $rowSpan = pow(2,$howDeep);

    ob_start();
    require plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/pedigree-online-report-pedigree-cell.php';
    $html = ob_get_contents();
    ob_end_clean();

    $html .= $father;
    // If the father ended a row, start a new one...
    if (preg_match('@</tr>$@',$father)) $html .= '<tr>';

    $html .= $mother;

    if ($endOfPedigree) $html .= '</tr>';

    return $html;
  }


  /**
  * Injects custom CSS into the footer if the setting is set...
  *
  * @since 1.0.0
  */
  public function inject_css() {

    $out = '';

    if ( Pedigree_Online_Functions::get_option('use_custom_colors') || Pedigree_Online_Functions::get_option('custom_css') ) {

        $out .= "<!-- Begin PedigreeOnline Custom Styles -->\n<style>\n";

        if ( Pedigree_Online_Functions::get_option('use_custom_colors') ) {

          foreach ( array('male','female') as $sex ) {

            if ( $color = Pedigree_Online_Functions::get_option( $sex . '_background_color' ) ) {
              $out .= ".pedigreeonline table td.pedigree-gender-" . $sex . " {\n";
              $out .= "  background: " . $color . ";\n";
              $out .= "}\n";
            }

            if ( $color = Pedigree_Online_Functions::get_option( $sex . '_text_color' ) ) {
              $out .= ".pedigreeonline table td.pedigree-gender-" . $sex . " .pedigree-name {\n";
              $out .= "  color: " . $color . ";\n";
              $out .= "}\n";
            }

          }

        }

        // If we have custom styles, display them here
        $out .= Pedigree_Online_Functions::get_option('custom_css');

        $out .= "\n</style>\n<!-- End PedigreeOnline Custom Styles -->\n";

    }

    print $out;

  }

  /**
	 * Render a progeny report based on the animal data
	 *
	 * @since    1.0.0
	 */
	 public function render_offspring( $data ) {

	    // Buffer output
	    ob_start();
	    require plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/pedigree-online-report-offspring.php';
	    $html = ob_get_contents();
	    ob_end_clean();

	    return $html;

	 }


	 /**
	 * Render a pedigree based on the animal data from a saved hypomating
	 *
	 * @since    1.1.0
	 */
	 public function render_saved_hypomating( $data ) {

	   return $this->render_pedigree($data);

	 }

   /**
	 * Render a notice div
	 *
	 * @since    1.0.0
	 */
	 public function render_notice( $message, $type = 'success' ) {

	    $out = '<div class="wrap">' .
	           '<div class="pedigreeonline">' .
	           '<div class="notice notice-'. $type .'">' .
	           '<p><strong>'.__("Pedigree Online Plugin").'</strong></p>'.
      	     '<p>'.$message.'</p>' .
      	     '</div>' .
      	     '</div>' .
             '</div>';

      return $out;

	 }


}
